# Release process

**TODO some notes for now**

## Preparations
* Announce code feature freeze on the mailing list.

## Tracking
Create a master release issue: https://github.com/log2timeline/plaso/issues/new. This issue is used to track the overall process of the release and should not contain much detail. For detail link to separate issues:

Use the github markdown notation:
```
* [ ] open action item
* [x] ~~completed action item~~
```

This will add a status bar indicating the progress of the release.

Create a release issue label: https://github.com/log2timeline/plaso/labels

Mark issues that need to be addressed before the release with the label and reference them in the master issue.

## Testing
* **TODO add link to test plan**

## Release
* Packaging
* Blog post

### Check list
* [ ] Are the Ubuntu packages in [GIFT](https://launchpad.net/~gift) up to date?
* [ ] Are the Mac OS X packages in [l2tbinaries](https://github.com/log2timeline/l2tbinaries) up to date?
* [ ] Are the Windows 32-bit packages in [l2tbinaries](https://github.com/log2timeline/l2tbinaries) up to date?
* [ ] Are the Windows 64-bit packages in [l2tbinaries](https://github.com/log2timeline/l2tbinaries) up to date?

## Aftercare
* Announce code feature freeze is over on the mailing list.